==> json-schema-for-humans-0.33.0.tar.gz: json-schema-for-humans-0.33.0/docs/examples/examples_md_nested_with_badges/recursive_parent_in_definition.md <==
# Person

- [1. [Optional] Property Person > relationships](#relationships)
  - [1.1. [Optional] Property Person > relationships > mother](#relationships_mother)
    - [1.1.1. [Optional] Property Person > relationships > mother > relationships](#relationships_mother_relationships)
      - [1.1.1.1. [Optional] Property Person > relationships > mother > relationships > mother](#relationships_mother_relationships_mother)

**Title:** Person

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

<details>
<summary><strong> <a name="relationships"></a>1. [Optional] Property Person > relationships</strong>  

</summary>
<blockquote>

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
| **Defined in**            | #/definitions/person/properties/relationships                                                                       |
|                           |                                                                                                                     |

**Description:** Relationships between this person and others

<details>
<summary><strong> <a name="relationships_mother"></a>1.1. [Optional] Property Person > relationships > mother</strong>  

</summary>
<blockquote>

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
| **Defined in**            | #/definitions/person                                                                                                |
|                           |                                                                                                                     |

**Description:** A human being

<details>
<summary><strong> <a name="relationships_mother_relationships"></a>1.1.1. [Optional] Property Person > relationships > mother > relationships</strong>  

</summary>
<blockquote>

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

**Description:** Relationships between this person and others

<details>
<summary><strong> <a name="relationships_mother_relationships_mother"></a>1.1.1.1. [Optional] Property Person > relationships > mother > relationships > mother</strong>  

</summary>
<blockquote>

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
| **Same definition as**    | `[mother](#relationships_mother)`                                                                                   |
|                           |                                                                                                                     |

**Description:** A human being

</blockquote>
</details>

</blockquote>
</details>

</blockquote>
</details>

</blockquote>
</details>

----------------------------------------------------------------------------------------------------------------------------
Generated using [json-schema-for-humans](https://github.com/coveooss/json-schema-for-humans) on date

==> json-schema-for-humans-0.34.0.tar.gz: json-schema-for-humans-0.34.0/docs/examples/examples_md_nested_with_badges/recursive_parent_in_definition.md <==
# Person

- [1. [Optional] Property Person > relationships](#relationships)
  - [1.1. [Optional] Property Person > relationships > mother](#relationships_mother)
    - [1.1.1. [Optional] Property Person > relationships > mother > relationships](#relationships_mother_relationships)
      - [1.1.1.1. [Optional] Property Person > relationships > mother > relationships > mother](#relationships_mother_relationships_mother)

**Title:** Person

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

<details>
<summary><strong> <a name="relationships"></a>1. [Optional] Property Person > relationships</strong>  

</summary>
<blockquote>

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
| **Defined in**            | #/definitions/person/properties/relationships                                                                       |
|                           |                                                                                                                     |

**Description:** Relationships between this person and others

<details>
<summary><strong> <a name="relationships_mother"></a>1.1. [Optional] Property Person > relationships > mother</strong>  

</summary>
<blockquote>

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
| **Defined in**            | #/definitions/person                                                                                                |
|                           |                                                                                                                     |

**Description:** A human being

<details>
<summary><strong> <a name="relationships_mother_relationships"></a>1.1.1. [Optional] Property Person > relationships > mother > relationships</strong>  

</summary>
<blockquote>

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

**Description:** Relationships between this person and others

<details>
<summary><strong> <a name="relationships_mother_relationships_mother"></a>1.1.1.1. [Optional] Property Person > relationships > mother > relationships > mother</strong>  

</summary>
<blockquote>

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
| **Same definition as**    | [mother](#relationships_mother)                                                                                     |
|                           |                                                                                                                     |

**Description:** A human being

</blockquote>
</details>

</blockquote>
</details>

</blockquote>
</details>

</blockquote>
</details>

----------------------------------------------------------------------------------------------------------------------------
Generated using [json-schema-for-humans](https://github.com/coveooss/json-schema-for-humans) on date
